==> haskell-unbounded-delays-0.1.1.0-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-unbounded-delays.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: unbounded-delays
version: 0.1.1.0
id: unbounded-delays-0.1.1.0-DDUOQpbBpLjIuQvgx5NepI
key: unbounded-delays-0.1.1.0-DDUOQpbBpLjIuQvgx5NepI
license: BSD3
copyright: 2011-2012 Bas van Dijk & Roel van Dijk
maintainer: Bas van Dijk <v.dijk.bas@gmail.com>
            Roel van Dijk <vandijk.roel@gmail.com>
homepage: https://github.com/basvandijk/unbounded-delays
synopsis: Unbounded thread delays and timeouts
description:
    The @threadDelay@ and @timeout@ functions from the @base@ library
    use the bounded @Int@ type for specifying the delay or timeout
    period. This packages provides alternatives which use the
    unbounded @Integer@ type.
category: Concurrency
author: Bas van Dijk <v.dijk.bas@gmail.com>
        Roel van Dijk <vandijk.roel@gmail.com>
exposed: True
exposed-modules:
    Control.Concurrent.Thread.Delay Control.Concurrent.Timeout
abi: de08e4161fad53438e30f8c108a8f444
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/unbounded-delays-0.1.1.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/unbounded-delays-0.1.1.0
data-dir: /usr/share/i386-linux-ghc-8.0.1/unbounded-delays-0.1.1.0
hs-libraries: HSunbounded-delays-0.1.1.0-DDUOQpbBpLjIuQvgx5NepI
depends:
    base-4.9.0.0
haddock-interfaces: /usr/share/doc/haskell-unbounded-delays/html/unbounded-delays.haddock
haddock-html: /usr/share/doc/haskell-unbounded-delays/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-unbounded-delays-0.1.1.0-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-unbounded-delays.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: unbounded-delays
version: 0.1.1.0
id: unbounded-delays-0.1.1.0-8pvOsE97fmS7WDAN5vUbqX
key: unbounded-delays-0.1.1.0-8pvOsE97fmS7WDAN5vUbqX
license: BSD3
copyright: 2011-2012 Bas van Dijk & Roel van Dijk
maintainer: Bas van Dijk <v.dijk.bas@gmail.com>
            Roel van Dijk <vandijk.roel@gmail.com>
homepage: https://github.com/basvandijk/unbounded-delays
synopsis: Unbounded thread delays and timeouts
description:
    The @threadDelay@ and @timeout@ functions from the @base@ library
    use the bounded @Int@ type for specifying the delay or timeout
    period. This packages provides alternatives which use the
    unbounded @Integer@ type.
category: Concurrency
author: Bas van Dijk <v.dijk.bas@gmail.com>
        Roel van Dijk <vandijk.roel@gmail.com>
exposed: True
exposed-modules:
    Control.Concurrent.Thread.Delay Control.Concurrent.Timeout
abi: 14b4ab85a78d917c5fce54aacd8457b8
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/unbounded-delays-0.1.1.0
library-dirs: /usr/lib/ghc-8.0.2/site-local/unbounded-delays-0.1.1.0
dynamic-library-dirs: /usr/lib/i386-linux-ghc-8.0.2
data-dir: /usr/share/i386-linux-ghc-8.0.2/unbounded-delays-0.1.1.0
hs-libraries: HSunbounded-delays-0.1.1.0-8pvOsE97fmS7WDAN5vUbqX
depends:
    base-4.9.1.0
haddock-interfaces: /usr/share/doc/haskell-unbounded-delays/html/unbounded-delays.haddock
haddock-html: /usr/share/doc/haskell-unbounded-delays/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
